@@ -321,4 +321,54 @@ class AirtelMoney(object):
             )
         )
         return self.response
+
+# Function used by support for direct status verification
+
+    def getStatus(self, operation_id):
+        """
+        Function for checking the status of a transaction at Airtel.
+        Used by support N1 without altering actual app in production.
+        I added this separate function because Airtel's network is unstable.
+
+        Parameter:
+            operation_id (str): Blueline's internal reference of the transaction
+        Return:
+            tuple of (status, Airtel_response)
+        """
+        LOGS.logger.info("[AirtelMoney][{}] Sending request...\n\n".format(operation_id))
+        body = {
+            "COMMAND": {
+                "TYPE": "TXNEQREQ",
+                "INTERFACEID": "BLUELINEIZY",
+                "EXTTRID": operation_id,
+            }
+        }
+        try:
+            response = requests.post(
+                AIRTEL_MONEY['url_status'],
+                data=xmltodict.unparse(body),
+                headers=self.headers,
+                verify=AIRTEL_MONEY['certificate_status'],
+            )
+            root = ElementTree.XML(response.text)
+            response_content = XmlDictConfig(root)
+            response_status = response_content.get('TXNSTATUS')
+            am_status = {
+                "TS": "Transaction validée",
+                "TF": "Transaction annulée",
+                "TA": "Transaction annulée",
+                "TIP": "En attente de paiement",
+            }
+            return (am_status[response_status], response_content)
+        except Exception as e:
+            LOGS.logger.error(
+                "[AirtelMoney][{}] {}\n\n".format(
+                    operation_id,
+                    str(e)
+                )
+            )
+            return (
+                500,
+                "Une erreur est survenue. Veuillez recommencer l'operation."
+            )
 # EOF
